@@ -1,5 +1,4 @@
 # pylint: skip-file
-# type: ignore
 
 import os
 import shutil
@@ -11,12 +10,12 @@ import trnsysGUI.createSinglePipePortItem as _cspi
 import trnsysGUI.images as _img
 import trnsysGUI.massFlowSolver.networkModel as _mfn
 from trnsysGUI.BlockItem import BlockItem
-from trnsysGUI.MyQFileSystemModel import MyQFileSystemModel
-from trnsysGUI.MyQTreeView import MyQTreeView
-from trnsysGUI.massFlowSolver import InternalPiping, MassFlowNetworkContributorMixin
+from trnsysGUI.MyQFileSystemModel import MyQFileSystemModel  # type: ignore[attr-defined]
+from trnsysGUI.MyQTreeView import MyQTreeView  # type: ignore[attr-defined]
+import trnsysGUI.internalPiping as _ip
 
 
-class AirSourceHP(BlockItem, MassFlowNetworkContributorMixin):
+class AirSourceHP(BlockItem, _ip.HasInternalPiping):
     def __init__(self, trnsysType, parent, **kwargs):
         super(AirSourceHP, self).__init__(trnsysType, parent, **kwargs)
 
@@ -28,12 +27,15 @@ class AirSourceHP(BlockItem, MassFlowNetworkContributorMixin):
         self.changeSize()
         self.addTree()
 
-    def getInternalPiping(self) -> InternalPiping:
-        inputPort = _mfn.PortItem("input", _mfn.PortItemType.INPUT)
-        outputPort = _mfn.PortItem("output", _mfn.PortItemType.OUTPUT)
-        pipe = _mfn.Pipe(self.displayName, self.trnsysId, inputPort, outputPort)
+    def getDisplayName(self) -> str:
+        return self.displayName
 
-        return InternalPiping([pipe], {inputPort: self.inputs[0], outputPort: self.outputs[0]})
+    def getInternalPiping(self) -> _ip.InternalPiping:
+        inputPort = _mfn.PortItem("In", _mfn.PortItemDirection.INPUT)
+        outputPort = _mfn.PortItem("Out", _mfn.PortItemDirection.OUTPUT)
+        pipe = _mfn.Pipe(inputPort, outputPort)
+
+        return _ip.InternalPiping([pipe], {inputPort: self.inputs[0], outputPort: self.outputs[0]})
 
     def _getImageAccessor(self) -> _tp.Optional[_img.ImageAccessor]:
         return _img.AIR_SOURCE_HP_SVG
@@ -98,15 +100,11 @@ class AirSourceHP(BlockItem, MassFlowNetworkContributorMixin):
         self.tree.setSortingEnabled(True)
         self.parent.parent().splitter.addWidget(self.tree)
 
-    def hasDdckPlaceHolders(self):
-        return True
-
     def deleteBlock(self):
         """
         Overridden method to also delete folder
         """
         self.logger.debug("Block " + str(self) + " is deleting itself (" + self.displayName + ")")
-        self.deleteConns()
         self.parent.parent().trnsysObj.remove(self)
         self.logger.debug("deleting block " + str(self) + self.displayName)
         self.parent.scene().removeItem(self)
