@@ -5,32 +5,48 @@ import json
 import typing as tp
 
 from trnsysGUI.AirSourceHP import AirSourceHP
-from trnsysGUI.BlockItem import BlockItem
 from trnsysGUI.Boiler import Boiler
+from trnsysGUI.CentralReceiver import CentralReceiver
 from trnsysGUI.Collector import Collector
-from trnsysGUI.Connection import Connection
-from trnsysGUI.Connector import Connector
+from trnsysGUI.connectors.connector import Connector
 from trnsysGUI.Control import Control
+from trnsysGUI.doublePipePortItem import DoublePipePortItem
 from trnsysGUI.ExternalHx import ExternalHx
 from trnsysGUI.GenericBlock import GenericBlock
 from trnsysGUI.Graphicaltem import GraphicalItem
 from trnsysGUI.GroundSourceHx import GroundSourceHx
-from trnsysGUI.Group import Group
 from trnsysGUI.HPDoubleDual import HPDoubleDual
+from trnsysGUI.HPDual import HPDual
 from trnsysGUI.HeatPump import HeatPump
 from trnsysGUI.HeatPumpTwoHx import HeatPumpTwoHx
 from trnsysGUI.IceStorage import IceStorage
 from trnsysGUI.IceStorageTwoHx import IceStorageTwoHx
 from trnsysGUI.MasterControl import MasterControl
+from trnsysGUI.ParabolicTroughField import ParabolicTroughField
 from trnsysGUI.PV import PV
 from trnsysGUI.PitStorage import PitStorage
-from trnsysGUI.Pump import Pump
+from trnsysGUI.pump import Pump
 from trnsysGUI.Radiator import Radiator
-from trnsysGUI.StorageTank import StorageTank
+from trnsysGUI.SaltTankCold import SaltTankCold
+from trnsysGUI.SaltTankHot import SaltTankHot
+from trnsysGUI.singlePipePortItem import SinglePipePortItem
+from trnsysGUI.SteamPowerBlock import SteamPowerBlock
 from trnsysGUI.TVentil import TVentil
 from trnsysGUI.TeePiece import TeePiece
 from trnsysGUI.WTap import WTap
 from trnsysGUI.WTap_main import WTap_main
+from trnsysGUI.connection.doublePipeConnection import DoublePipeConnection
+from trnsysGUI.connection.singlePipeConnection import SinglePipeConnection
+from trnsysGUI.connectors.doubleDoublePipeConnector import DoubleDoublePipeConnector
+from trnsysGUI.doublePipeTeePiece import DoublePipeTeePiece
+from trnsysGUI.connectors.singleDoublePipeConnector import SingleDoublePipeConnector
+from trnsysGUI.storageTank.widget import StorageTank
+from trnsysGUI.source import Source
+from trnsysGUI.sink import Sink
+from trnsysGUI.sourceSink import SourceSink
+from trnsysGUI.geotherm import Geotherm
+from trnsysGUI.water import Water
+from trnsysGUI.crystalizer import Crystalizer
 
 
 class Decoder(json.JSONDecoder):
@@ -78,18 +94,6 @@ class Decoder(json.JSONDecoder):
                 if type(i) is not dict:
                     continue
 
-                if ".__GroupDict__" in i:
-                    self.logger.debug("Found the group dict")
-                    self.logger.debug("Decoding group " + str(i["GroupName"]))
-
-                    groupListNames = [g.displayName for g in self.editor.groupList]
-
-                    if i["GroupName"] not in groupListNames:
-                        g = Group(
-                            i["Position"][0], i["Position"][1], i["Size"][0], i["Size"][1], self.editor.diagramScene
-                        )
-                        g.setName(i["GroupName"])
-
                 # Adding the blocks to the scene could also be done inside Decoder now (before not possible because
                 # no way of accessing the diagramView)
 
@@ -107,8 +111,12 @@ class Decoder(json.JSONDecoder):
                         bl = Pump(
                             i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
                         )
-                    elif i["BlockName"] == "Collector":
+                    elif i["BlockName"] in ("Collector", "Kollektor"):
                         bl = Collector(
+                            "Collector", self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "CSP_CR":
+                        bl = CentralReceiver(
                             i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
                         )
                     elif i["BlockName"] == "HP":
@@ -127,6 +135,18 @@ class Decoder(json.JSONDecoder):
                         bl = Radiator(
                             i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
                         )
+                    elif i["BlockName"] == "coldSaltTank":
+                        bl = SaltTankCold(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "hotSaltTank":
+                        bl = SaltTankHot(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"]  == "powerBlock":
+                        bl = SteamPowerBlock(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
                     elif i["BlockName"] == "WTap":
                         bl = WTap(
                             i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
@@ -147,6 +167,10 @@ class Decoder(json.JSONDecoder):
                         bl = AirSourceHP(
                             i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
                         )
+                    elif i["BlockName"] == "CSP_PT":
+                        bl = ParabolicTroughField(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
                     elif i["BlockName"] == "PV":
                         bl = PV(
                             i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
@@ -173,6 +197,10 @@ class Decoder(json.JSONDecoder):
                         bl = HPDoubleDual(
                             i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
                         )
+                    elif i["BlockName"] == "HPDual":
+                        bl = HPDual(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
                     elif i["BlockName"] == "ExternalHx":
                         bl = ExternalHx(
                             i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
@@ -198,21 +226,59 @@ class Decoder(json.JSONDecoder):
                     elif i["BlockName"] == "GraphicalItem":
                         bl = GraphicalItem(self.editor.diagramView, loadedGI=True)
 
+                    elif i["BlockName"] == "DPTee":
+                        bl = DoublePipeTeePiece(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "SPCnr":
+                        bl = SingleDoublePipeConnector(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "DPCnr":
+                        bl = DoubleDoublePipeConnector(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "Sink":
+                        bl = Sink(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "Source":
+                        bl = Source(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "SourceSink":
+                        bl = SourceSink(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "Geotherm":
+                        bl = Geotherm(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "Water":
+                        bl = Water(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+                    elif i["BlockName"] == "Crystalizer":
+                        bl = Crystalizer(
+                            i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"], loadedBlock=True
+                        )
+
                     else:
-                        bl = BlockItem(i["BlockName"], self.editor.diagramView, displayName=i["BlockDisplayName"])
+                        raise AssertionError(f"Unknown kind of block item: {i['BlockName']}")
 
                     bl.decode(i, resBlockList)
 
                 elif ".__ConnectionDict__" in i:
-                    fromPort = None
-                    toPort = None
+                    fromPortId, toPortId = self._getPortIds(i)
 
                     # Looking for the ports the connection is connected to
+                    fromPort = None
+                    toPort = None
                     for connBl in resBlockList:
                         for p in connBl.inputs + connBl.outputs:
-                            if p.id == i["PortFromID"]:
+                            if p.id == fromPortId:
                                 fromPort = p
-                            if p.id == i["PortToID"]:
+                            if p.id == toPortId:
                                 toPort = p
 
                     if fromPort is None:
@@ -221,10 +287,12 @@ class Decoder(json.JSONDecoder):
                     if toPort is None:
                         self.logger.debug("Error: Did not found a toPort")
 
-                    connectionKwargs = self.create_connection_kwargs(i)
-
-                    c = Connection(fromPort, toPort, self.editor, **connectionKwargs)
-
+                    if isinstance(fromPort, SinglePipePortItem) and isinstance(toPort, SinglePipePortItem):
+                        c = SinglePipeConnection(fromPort, toPort, self.editor)
+                    elif isinstance(fromPort, DoublePipePortItem) and isinstance(toPort, DoublePipePortItem):
+                        c = DoublePipeConnection(fromPort, toPort, self.editor)
+                    else:
+                        raise AssertionError("`fromPort' and `toPort' have different types.")
                     c.decode(i)
                     resConnList.append(c)
 
@@ -240,19 +308,14 @@ class Decoder(json.JSONDecoder):
         return arr
 
     @staticmethod
-    def create_connection_kwargs(item: tp.Mapping[str, tp.Any]) -> tp.Mapping[str, tp.Any]:
-        connectionKwargs = dict(
-            loadedConn=True,
-            fromPortId=item["PortFromID"],
-            toPortId=item["PortToID"],
-            segmentsLoad=item["SegmentPositions"],
-            cornersLoad=item["CornerPositions"],
-        )
-
-        if "FirstSegmentLabelPos" in item:
-            connectionKwargs["labelPos"] = tuple(item["FirstSegmentLabelPos"])
-
-        if "FirstSegmentMassFlowLabelPos" in item:
-            connectionKwargs["labelMassPos"] = tuple(item["FirstSegmentMassFlowLabelPos"])
-
-        return connectionKwargs
+    def _getPortIds(i):
+        if "PortFromID" in i and "PortToID" in i:
+            # Legacy port ID naming
+            fromPortId = i["PortFromID"]
+            toPortId = i["PortToID"]
+        elif "fromPortId" in i and "toPortId" in i:
+            fromPortId = i["fromPortId"]
+            toPortId = i["toPortId"]
+        else:
+            raise AssertionError("Could not find port IDs for connection.")
+        return fromPortId, toPortId
